@@ -396,7 +396,13 @@ class ComputedSource(Computation):
         return len(self.items)
 
     def _start_computation(self):
-        self.items = list(self.f(*self.args))
+        args = self.args
+        if len(args) == 1 and isinstance(args[0], Source):
+            args = args[0].items
+            assert len(args) == 1, "exepected source which only produces one data item"
+        else:
+            args = self.args
+        self.items = list(self.f(*args))
         for i, item in enumerate(self.items):
             self.put(EnumeratedItem(i, item))
 
